'''
Comments examples.

:copyright: Copyright 2021 AXY axy@declassed.art
:license: BSD, see LICENSE for details.
'''

from textwrap import dedent

from .. import Template, CommentMixin

class GoodTemplate(Template, CommentMixin):

    # Example 1.
    # Comments may span multiple lines.
    snippet1 = dedent('''
        The red dog
        {comment: or fox?}
        jumps over the lazy fox. {comment: at last, maybe it's
        a fox who jumps over the lazy dog?}
    ''')
    result1 = dedent('''
        The red dog

        jumps over the lazy fox.
    ''')

    # Example 2.
    # Braces in comments should be escaped, otherwise they are treated as substitutions.
    snippet2 = dedent('''
        {comment: Braces should be escaped like this: {{ }}, otherwise it's a {substitution}}
    ''')
    substitution = 'blah blah blah'
    result2 = '\n'

class BadTemplate1(Template, CommentMixin):

    # Example 3.
    # Same as example 2 in GoodTemplate. We do not define substitution so this fails.
    snippet = dedent('''
        {comment: Braces should be escaped like this: {{ }}, otherwise it's a {substitution}}
    ''')
    result = '\n'

def test_comments():
    template = GoodTemplate()
    context = template.render()
    assert context['snippet1'].strip() == template.result1.strip()
    assert context['snippet2'].strip() == template.result2.strip()

    try:
        template = BadTemplate1()
        context = template.render()
        print(context['snippet'])
        assert False, 'WTF? BadTemplate1 should fail!'
    except AttributeError as e:
        assert e.args[0] == 'BadTemplate1 does not provide substitution'
