'''
Pygments examples.

:copyright: Copyright 2021 AXY axy@declassed.art
:license: BSD, see LICENSE for details.
'''

from textwrap import dedent

from ..markup import MarkupTemplate
from ..extras.pygments import PygmentsMixin

class BasicExample(MarkupTemplate, PygmentsMixin):

    snippet = dedent('''
        {pygments:highlight('python', """
            def main():
                # XXX: simple thing
                print('Hello, world!')
        """)}
    ''')
    result = dedent('''
        <div class="highlight"><pre><span></span><span class="k">def</span> <span class="nf">main</span><span class="p">():</span>
            <span class="c1"># XXX: simple thing</span>
            <span class="nb">print</span><span class="p">(</span><span class="s1">&#39;Hello, world!&#39;</span><span class="p">)</span>
        </pre></div>
    ''')

class FiltersExample(MarkupTemplate, PygmentsMixin):

    snippet = dedent('''
        {pygments:highlight('python', """
            def main():
                # XXX: simple thing
                print('Hello, world!')
        """,
        filters = [('codetagify', {{}})])}
    ''')
    result = dedent('''
        <div class="highlight"><pre><span></span><span class="k">def</span> <span class="nf">main</span><span class="p">():</span>
            <span class="c1"># </span><span class="cs">XXX</span><span class="c1">: simple thing</span>
            <span class="nb">print</span><span class="p">(</span><span class="s1">&#39;Hello, world!&#39;</span><span class="p">)</span>
        </pre></div>
    ''')

def test_pygments():
    template = BasicExample()
    context = template.render()
    assert context['snippet'].strip() == template.result.strip()

    template = FiltersExample()
    context = template.render()
    assert context['snippet'].strip() == template.result.strip()
